@@ -3,6 +3,10 @@
 require "spec_helper"
 
 RSpec.describe Lumberjack::Formatter::RedactFormatter do
+  it "is registered as :redact" do
+    expect(Lumberjack::FormatterRegistry.formatter(:redact)).to be_a(Lumberjack::Formatter::RedactFormatter)
+  end
+
   it "should redact long strings" do
     formatter = Lumberjack::Formatter::RedactFormatter.new
     expect(formatter.call("1234567890")).to eq("12******90")
